==> piwigo-2.1.3.zip: piwigo/language/hr_HR/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2009 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Installation'] = 'Ugradba';
$lang['Basic configuration'] = 'Osnovna postava';
$lang['Default gallery language'] = 'Pretpostavljeni jezik galerije';
$lang['Database configuration'] = 'Postava baze podataka';
$lang['Admin configuration'] = 'Upravna postava';
$lang['Start Install'] = 'Pokreni ugradbu';
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = 'e-mail adresa mora biti kao xxx@yyy.eee (example : jere@stranica.org)';

$lang['Webmaster login'] = 'Webmaster-ova prijava';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Biti će prikazano posjetiteljima. Potrebno je za upravljanje web mjestom';

$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Povezivanje sa poslužiteljem uspješno, ali je nemoguće povezivanje sa bazom podataka';
$lang['Can\'t connect to server'] = 'Ne mogu se povezati sa poslužiteljem';

$lang['Host'] = 'MySQL poslužitelj';
$lang['localhost, sql.multimania.com, toto.freesurf.fr'] = 'localhost, sql.multimania.com, toto.freesurf.fr';
$lang['User'] = 'Korisnik';
$lang['user login given by your host provider'] = 'korisničko ime dobiveno od davatelja usluge smještaja';
$lang['Password'] = 'Zaporka';
$lang['user password given by your host provider'] = 'korisnička zaporka dobivena od davatelja usluge smještaja';
$lang['Database name'] = 'Naziv baze podataka';
$lang['also given by your host provider'] = 'također dobivena od davatelja usluge smještaja';
$lang['Database table prefix'] = 'Predznak tabela baze podataka';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'nazivi tabela baze podataka će biti predznačeni sa time (omogućava vam bolje upravljanje tabelama)';
$lang['enter a login for webmaster'] = 'upišite korisničko ime za webmaster-a';
$lang['webmaster login can\'t contain characters \' or "'] = 'webmaster-ovo korisničko ime ne može sadržavati znakove \' ili "';
$lang['please enter your password again'] = 'molimo upišite zaporku ponovo';
$lang['Webmaster password'] = 'Webmaster-ova zaporka';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Čuvajte je na sigurnom mjestu, ona omogućava pristup upravnoj ploči';
$lang['Password [confirm]'] = 'Zaporka [potvrdi]';
$lang['verification'] = 'ovjera';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Trebate pomoć? Pitajte na <a href="%s">Piwigo message board</a>.';
$lang['Webmaster mail address'] = 'Webmaster-ova e-mail adresa';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Posjetitelji će moći pisati upravitelju galerije preko ove adrese';

// piwigo 2.1
$lang['Database type'] = 'Vrsta baze podataka';
$lang['The type of database your piwigo data will be store in'] = 'Vrsta baze podataka u kojoj će se pohraniti vaši Piwigo podatci';
$lang['PHP 5 is required'] = 'PHP 5 je obvezan';
$lang['It appears your webhost is currently running PHP %s.'] = 'Čini se da vaše web mjesto trenutno koristi PHP inačicu %s.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo će pokušati podesiti sustavne postavke na PHP 5 izradom ili prilagodbom .htaccess zapisa.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Ne zaboravite da možete i sami promijeniti postavke te potom ponovo pokrenuti Piwigo.';
$lang['Try to configure PHP 5'] = 'Pokušaj podešavanja PHP 5';
$lang['Sorry!'] = 'Nažalost!';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo nije u mogućnosti podesiti PHP 5.';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Trebate se obratiti vašem davatelju usluge smještaja za upute na koji se način možete prebaciti na PHP 5 samostalno.';
$lang['Hope to see you back soon.'] = 'Do skorog viđenja.';
$lang['Congratulations, Piwigo installation is completed'] = 'Čestitamo, Piwigo ugradnja je dovršena';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Druga mogućnost je da kopirate tekst u prostoru poviše i prebacite ga u zapis "local/config/database.inc.php" (Pozor :u database.inc.php smije se prebaciti samo tekst iz kućice bez znakova novog reda ili praznog prostora)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Izrada local/config/database.inc.php nije uspjela.';
$lang['Download the config file'] = 'Preuzmi zapis podešavanja';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Možete preuzeti zapis sustavnog podešavanja i prebaciti ga u local/config mapu vaše ugradnje.';

?>

==> piwigo-2.2.4.zip: piwigo/language/hr_HR/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2009 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Installation'] = 'Ugradba';
$lang['Basic configuration'] = 'Osnovna postava';
$lang['Default gallery language'] = 'Pretpostavljeni jezik galerije';
$lang['Database configuration'] = 'Postava baze podataka';
$lang['Admin configuration'] = 'Upravna postava';
$lang['Start Install'] = 'Pokreni ugradbu';
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = 'e-mail adresa mora biti kao xxx@yyy.eee (example : jere@stranica.org)';

$lang['Webmaster login'] = 'Webmaster-ova prijava';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Biti će prikazano posjetiteljima. Potrebno je za upravljanje web mjestom';

$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Povezivanje sa poslužiteljem uspješno, ali je nemoguće povezivanje sa bazom podataka';
$lang['Can\'t connect to server'] = 'Ne mogu se povezati sa poslužiteljem';

$lang['Host'] = 'MySQL poslužitelj';
$lang['localhost, sql.multimania.com, toto.freesurf.fr'] = 'localhost, sql.multimania.com, toto.freesurf.fr';
$lang['User'] = 'Korisnik';
$lang['user login given by your host provider'] = 'korisničko ime dobiveno od davatelja usluge smještaja';
$lang['Password'] = 'Zaporka';
$lang['user password given by your host provider'] = 'korisnička zaporka dobivena od davatelja usluge smještaja';
$lang['Database name'] = 'Naziv baze podataka';
$lang['also given by your host provider'] = 'također dobivena od davatelja usluge smještaja';
$lang['Database table prefix'] = 'Predznak tabela baze podataka';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'nazivi tabela baze podataka će biti predznačeni sa time (omogućava vam bolje upravljanje tabelama)';
$lang['enter a login for webmaster'] = 'upišite korisničko ime za webmaster-a';
$lang['webmaster login can\'t contain characters \' or "'] = 'webmaster-ovo korisničko ime ne može sadržavati znakove \' ili "';
$lang['please enter your password again'] = 'molimo upišite zaporku ponovo';
$lang['Webmaster password'] = 'Webmaster-ova zaporka';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Čuvajte je na sigurnom mjestu, ona omogućava pristup upravnoj ploči';
$lang['Password [confirm]'] = 'Zaporka [potvrdi]';
$lang['verification'] = 'ovjera';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Trebate pomoć? Pitajte na <a href="%s">Piwigo message board</a>.';
$lang['Webmaster mail address'] = 'Webmaster-ova e-mail adresa';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Posjetitelji će moći pisati upravitelju galerije preko ove adrese';

// piwigo 2.1
$lang['Database type'] = 'Vrsta baze podataka';
$lang['The type of database your piwigo data will be store in'] = 'Vrsta baze podataka u kojoj će se pohraniti vaši Piwigo podatci';
$lang['PHP 5 is required'] = 'PHP 5 je obvezan';
$lang['It appears your webhost is currently running PHP %s.'] = 'Čini se da vaše web mjesto trenutno koristi PHP inačicu %s.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo će pokušati podesiti sustavne postavke na PHP 5 izradom ili prilagodbom .htaccess zapisa.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Ne zaboravite da možete i sami promijeniti postavke te potom ponovo pokrenuti Piwigo.';
$lang['Try to configure PHP 5'] = 'Pokušaj podešavanja PHP 5';
$lang['Sorry!'] = 'Nažalost!';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo nije u mogućnosti podesiti PHP 5.';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Trebate se obratiti vašem davatelju usluge smještaja za upute na koji se način možete prebaciti na PHP 5 samostalno.';
$lang['Hope to see you back soon.'] = 'Do skorog viđenja.';
$lang['Congratulations, Piwigo installation is completed'] = 'Čestitamo, Piwigo ugradnja je dovršena';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Druga mogućnost je da kopirate tekst u prostoru poviše i prebacite ga u zapis "local/config/database.inc.php" (Pozor :u database.inc.php smije se prebaciti samo tekst iz kućice bez znakova novog reda ili praznog prostora)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Izrada local/config/database.inc.php nije uspjela.';
$lang['Download the config file'] = 'Preuzmi zapis podešavanja';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Možete preuzeti zapis sustavnog podešavanja i prebaciti ga u local/config mapu vaše ugradnje.';

?>
